// Generated by gir (https://github.com/gtk-rs/gir @ be9aa145267c)
// from ../.. (@ b4c1dbc27547+)
// from ../../gir-files (@ 6cd7b656acd6)
// DO NOT EDIT

#include "manual.h"
#include <stdalign.h>
#include <stdio.h>

int main() {
    printf("%s;%zu;%zu\n", "PhoshDBusScreenshotProxyClass", sizeof(PhoshDBusScreenshotProxyClass), alignof(PhoshDBusScreenshotProxyClass));
    printf("%s;%zu;%zu\n", "PhoshDBusScreenshotSkeletonClass", sizeof(PhoshDBusScreenshotSkeletonClass), alignof(PhoshDBusScreenshotSkeletonClass));
    printf("%s;%zu;%zu\n", "PhoshLayerSurface", sizeof(PhoshLayerSurface), alignof(PhoshLayerSurface));
    printf("%s;%zu;%zu\n", "PhoshLayerSurfaceClass", sizeof(PhoshLayerSurfaceClass), alignof(PhoshLayerSurfaceClass));
    printf("%s;%zu;%zu\n", "PhoshLockscreen", sizeof(PhoshLockscreen), alignof(PhoshLockscreen));
    printf("%s;%zu;%zu\n", "PhoshLockscreenClass", sizeof(PhoshLockscreenClass), alignof(PhoshLockscreenClass));
    printf("%s;%zu;%zu\n", "PhoshLockscreenManagerClass", sizeof(PhoshLockscreenManagerClass), alignof(PhoshLockscreenManagerClass));
    printf("%s;%zu;%zu\n", "PhoshLockscreenPage", sizeof(PhoshLockscreenPage), alignof(PhoshLockscreenPage));
    printf("%s;%zu;%zu\n", "PhoshQuickSetting", sizeof(PhoshQuickSetting), alignof(PhoshQuickSetting));
    printf("%s;%zu;%zu\n", "PhoshQuickSettingClass", sizeof(PhoshQuickSettingClass), alignof(PhoshQuickSettingClass));
    printf("%s;%zu;%zu\n", "PhoshScreenshotManagerClass", sizeof(PhoshScreenshotManagerClass), alignof(PhoshScreenshotManagerClass));
    printf("%s;%zu;%zu\n", "PhoshShell", sizeof(PhoshShell), alignof(PhoshShell));
    printf("%s;%zu;%zu\n", "PhoshShellClass", sizeof(PhoshShellClass), alignof(PhoshShellClass));
    printf("%s;%zu;%zu\n", "PhoshStatusIcon", sizeof(PhoshStatusIcon), alignof(PhoshStatusIcon));
    printf("%s;%zu;%zu\n", "PhoshStatusIconClass", sizeof(PhoshStatusIconClass), alignof(PhoshStatusIconClass));
    printf("%s;%zu;%zu\n", "PhoshStatusPage", sizeof(PhoshStatusPage), alignof(PhoshStatusPage));
    printf("%s;%zu;%zu\n", "PhoshStatusPageClass", sizeof(PhoshStatusPageClass), alignof(PhoshStatusPageClass));
    printf("%s;%zu;%zu\n", "PhoshWallClock", sizeof(PhoshWallClock), alignof(PhoshWallClock));
    printf("%s;%zu;%zu\n", "PhoshWallClockClass", sizeof(PhoshWallClockClass), alignof(PhoshWallClockClass));
    return 0;
}
