// Generated by gir (https://github.com/gtk-rs/gir @ be9aa145267c)
// from ../.. (@ b4c1dbc27547+)
// from ../../gir-files (@ 6cd7b656acd6)
// DO NOT EDIT

#[cfg(not(docsrs))]
use std::process;

#[cfg(docsrs)]
fn main() {} // prevent linking libraries to avoid documentation failure

#[cfg(not(docsrs))]
fn main() {
    if let Err(s) = system_deps::Config::new().probe() {
        println!("cargo:warning={s}");
        process::exit(1);
    }
}
